@@ -3,6 +3,7 @@ import datetime
 import sqlalchemy as sa
 from formencode import htmlfill, variabledecode
 from formbar.renderer import FormRenderer, get_renderer
+from formbar.rules import Rule, Parser
 
 log = logging.getLogger(__name__)
 
@@ -174,9 +175,7 @@ class Form(object):
         deserialized = {}
         for fieldname, value in self._filter_values(data).iteritems():
             field = self.fields.get(fieldname)
-            if field and not field.is_readonly():
-                # Only add the value if the field is not marked as readonly
-                deserialized[fieldname] = self._to_python(field, data.get(field.name))
+            deserialized[fieldname] = self._to_python(field, data.get(field.name))
         log.debug("Deserialized values: %s" % deserialized)
         return deserialized
 
@@ -275,11 +274,14 @@ class Form(object):
     def add_validator(self, validator):
         return self.external_validators.append(validator)
 
-    def render(self, values={}, page=0, buttons=True):
+    def render(self, values={}, page=0, buttons=True, previous_values=None):
         """Returns the rendererd form as an HTML string.
 
         :values: Dictionary with values to be prefilled/overwritten in
         the rendered form.
+        :previous_values: Dictionary of values of the last saved state
+        of the item. If provided a diff between the current and previous
+        values will be renderered in readonly mode.
         :returns: Rendered form.
 
         """
@@ -297,8 +299,12 @@ class Form(object):
         values['csrf_token'] = self._csrf_token
 
         renderer = FormRenderer(self, self._translate)
-        form = renderer.render(values=values, buttons=buttons)
-        return htmlfill.render(form, values)
+        form = renderer.render(values=values, buttons=buttons,
+                               previous_values=previous_values)
+        try:
+            return htmlfill.render(form, values)
+        except AssertionError, e:
+            log.error("Error while parsing form in htmlfill: %s. Hint See 'https://github.com/formencode/formencode/issues/57'" % e.message)
 
     def _add_error(self, fieldname, error):
         field = self.get_field(fieldname)
@@ -536,10 +542,13 @@ class Form(object):
 
         if not submitted:
             unvalidated = self.loaded_data
+            # No need to convert the values here as the values are
+            # already pythonic when loaded from the item.
+            converted = unvalidated
         else:
             self.submitted_data = variabledecode.variable_decode(submitted)
             unvalidated = self.submitted_data
-        converted = self.deserialize(unvalidated)
+            converted = self.deserialize(unvalidated)
 
         # Validate the fields. Ignore fields which are disabled in
         # conditionals First get list of fields which are still in the
@@ -618,6 +627,7 @@ class Field(object):
         self._errors = []
         self._warnings = []
         self.value = ""
+        self.previous_value = None
         """Value as string of the field. Will be set on rendering the
         form"""
 
@@ -667,8 +677,16 @@ class Field(object):
     def set_value(self, value):
         self.value = value
 
+    def set_previous_value(self, value):
+        self.previous_value = value
+
     def get_value(self, default=None, expand=False):
-        value = self.value
+        return self._get_value(self.value, default, expand)
+
+    def get_previous_value(self, default=None, expand=False):
+        return self._get_value(self.previous_value, default, expand)
+
+    def _get_value(self, value, default, expand):
         if expand:
             if not isinstance(value, list):
                 value = [value]
@@ -680,27 +698,78 @@ class Field(object):
                         ex_values.append("%s" % opt[0])
             return ", ".join(ex_values)
         else:
-            return value
+            if value:
+                return value
+            elif default:
+                return default
+            else:
+                return value
+
+    def _build_filter_expr(self, expr_str, item):
+        t = expr_str.split(" ")
+        for x in t:
+            if x.startswith("%"):
+                key =  x.strip("%")
+                value = getattr(item, key)
+                if isinstance(value, list):
+                    value = "[%s]" % ", ".join("'%s'" % unicode(v) for v in value)
+                    expr_str = expr_str.replace(x, value)
+        p = Parser()
+        return p.parse(expr_str)
+
+    def _load_options_from_db(self):
+        # Get mapped clazz for the field
+        options = []
+        if self.get_type() == 'manytoone':
+            options.append(("None", "", True))
+        clazz = self._get_sa_mapped_class()
+        items = self._form._dbsession.query(clazz)
+        for item in items:
+            if self._config.renderer and self._config.renderer.filter:
+                expr = self._build_filter_expr(
+                    self._config.renderer.filter, item)
+                rule = Rule(expr)
+                if rule.evaluate({}):
+                    options.append((item, item.id, True))
+                else:
+                    options.append((item, item.id, False))
+            else:
+                options.append((item, item.id, True))
+        return options
 
     def get_options(self):
+        """Will return a list of tuples containing the options of the
+        field. The tuple contains in the following order:
+
+        1. the display value of the option,
+        2. its value and
+        3. a boolean flag if the options is a filtered one and
+        should not be visible in the selection.
+
+        Options can be filtered by defining the filter attribute of the
+        renderer. The expression will be applied on every option in the
+        selection. Keyword beginning with % are handled as variable. On
+        rule evaluation the keyword in the expression will be replaced
+        with the value of the item with the name of the variable.
+
+        Filtering is currently actually only done for selection based on
+        the SQLAlchemy model and which are loaded from the database.
+        """
+        options = []
         user_defined_options = self._config.options
         if user_defined_options:
-            return user_defined_options
+            for option in user_defined_options:
+                # TODO: Filter user defined options too (ti) <2014-02-19 23:46>
+                options.append((option[0], option[1], True))
         elif self._form._dbsession:
-            # Get mapped clazz for the field
-            options = []
-            if self.get_type() == 'manytoone':
-                options.append(("None", ""))
-            clazz = self._get_sa_mapped_class()
-            items = self._form._dbsession.query(clazz)
-            options.extend([(item, item.id) for item in items])
-            return options
+            return self._load_options_from_db()
         else:
             # TODO: Try to get the session from the item. Ther must be
             # somewhere the already bound session. (torsten) <2013-07-23 00:27>
             log.warning('No db connection configured for this form. Can '
                         'not load options')
             return []
+        return options
 
     def add_error(self, error):
         self._errors.append(error)
